((nil . ((compile-command . "guix shell emacs-minimal -- ./build-package")))
 (prog-mode (eval flymake-mode))
 (magit-status-mode (magit-todos-exclude-globs)))
